@@ -1,7 +1,9 @@
 use 5.016;
 
+# ABSTRACT: Proxy class for Mojo::UserAgent::Mockable that will not set any proxy.
+
 package Mojo::UserAgent::Mockable::Proxy;
-$Mojo::UserAgent::Mockable::Proxy::VERSION = '1.51';
+$Mojo::UserAgent::Mockable::Proxy::VERSION = '1.52';
 use Mojo::Base 'Mojo::UserAgent::Proxy';
 
 1;
@@ -17,11 +19,11 @@ __END__
 
 =head1 NAME
 
-Mojo::UserAgent::Mockable::Proxy
+Mojo::UserAgent::Mockable::Proxy - Proxy class for Mojo::UserAgent::Mockable that will not set any proxy.
 
 =head1 VERSION
 
-version 1.51
+version 1.52
 
 =head1 AUTHOR
 
